    <!-- Bootstrap core JavaScript ================================================== -->
    <!-- Placed at the end of the document so the pages load faster -->
    {% load staticfiles %}
    <script src='{% static "js/jquery-1.10.2.min.js" %}'></script>
    <script src='{% static "js/bootstrap.min.js" %}'></script>
    <script src='{% static "js/highlighter.js" %}'></script>
    <script>
        $("#contenido").highlight({{ keyword|safe }});
    </script>

    <script>
        (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
        (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
        m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
        })(window,document,'script','//www.google-analytics.com/analytics.js','ga');

        ga('create', 'UA-48290028-1', 'aniversarioperu.me');
        ga('send', 'pageview');
    </script>