{% extends 'base.html' %}
{% block title %}Manolo | Buscador de visitas, organismo de contrataciones PCM
{% endblock %}
{% block content %}
     </div><!-- container -->




     <div class="container" style="text-align:center; max-width:1200px;">
        <h2>Este es Manolo</h2>
            <b>Manolo es un buscador de las personas</b> que visitan las instalaciones del
            Organismo Supervisor de las Contrataciones del Estado.
            <br />
            Todos los datos son descargados diariamente de aquÃ­: <b><a href="http://visitas.osce.gob.pe/controlVisitas/index.php?r=consultas/visitaConsulta/index">
            http://visitas.osce.gob.pe/controlVisitas/index.php?r=consultas/visitaConsulta/index</a></b>
            </p>
            <div class='well'>
            Puedes buscar por nombre o palabra clave. Por ejemplo tipea
            <b>ROMULO</b> y hacer click en "Buscar".
            </div>
            <p>
            TambiÃ©n puedes hacer bÃºsquedas haciendo click sobre cada uno de los resultados.
            </p>


       <div class="row">
         <div class="col-xs-12 col-md-12 col-lg-12">
           <form action="{% url 'manolo:search' %}" method="get" class="form-inline" role="search">
             <div class="form-group">
                 <label class="sr-only" for="query">Keyword</label>
                 <input style="width:250px;" type="text" id="query" name="q"
                                   class="form-control"
                                   placeholder="Tipea persona o palabra clave" />
             </div>
               <button type="submit" class="btn btn-info" id="search_button">
                            <span class="glyphicon glyphicon-search"></span>
                            Buscar
               </button>
           </form>
         </div>
       </div><!-- row -->
     </div><!-- container -->

     <br />

     <div id="contenido" class="container" style="max-width:1200px;">



{% endblock %}

{% block disclaimer %}
{% include 'site/disclaimer.html' %}
{% endblock %}


{% block footer %}
  {% include 'site/footer.html' %}
{% endblock footer %}