<!DOCTYPE html>
<html lang="es" xmlns="http://www.w3.org/1999/html">
  <head>
    {% block additional_meta %}
    {% endblock additional_meta %}

    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Manolo. Buscador de visitas a
    entidades del Estado Peruano">
    <meta name="author" content="AniversarioPeru">
    {% load staticfiles %}
    <link rel="shortcut icon" href="{% static 'img/favicon.ico' %}">

    {% block title %}
      <title>Manolo. Buscador de visitas a instituciones del Estado</title>
    {% endblock title %}

    <link href="//maxcdn.bootstrapcdn.com/bootswatch/3.2.0/readable/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css">
    <style type="text/css">
        .form-group { display: inline-block; }
        .highlight { background-color: yellow }
        .navbar .divider-vertical {
            min-height: 50px;
            margin: 0 9px;
            border-right: 1px solid #ffffff;
            border-left: 1px solid #f2f2f2;
        }
        footer {
            padding-bottom: 20px;
            margin-bottom: 20px;
        }
    </style>

  </head>

  <body>


    <br />

  {% block content %}{% endblock content %}


    <br />



      <div class="container">
        <div class="well"><b>Disclaimer:</b> La info presentada
            en esta herramienta web (o sea <b>Manolo</b>) es referencial y no tiene valor legal.
            Para denuncias y otras cuestiones legales debes verificar con las fuentes originales
            (ej. el registro en línea de la
            institución estatal correspondiente).
        </div>


        <hr>
        <footer>
          <small class="pull-left">
            <a href="https://github.com/aniversarioperu/django-manolo/"><i class="fa fa-github-alt"></i>
              v2.3.2</a>
          </small>

            <small class="pull-right">
              &copy; 2015 Desarrollado por <a href="https://twitter.com/AniversarioPeru">AniversarioPeru <i class="fa fa-twitter"></i></a>
            </small>
        </footer>
      </div>


  {% load staticfiles %}
  <script src="//code.jquery.com/jquery-1.11.0.min.js"></script>
  <script src='{% static "js/highlighter.js" %}'></script>
  <script>$("#contenido").highlight('{{ query }}');</script>
  </body>
</html>