{% extends "base.html" %}

{% block title %}Server Error{% endblock %}

{% block content %}
	<h1>Uy curujus!</h1>

<p>
  Parece que el servidor tiene un error. Trataremos de corregirlo tan pronto como
  sea posible.
</p>
{% endblock content %}
