{% extends 'base.html' %}

{% block content %}
<div class="container" style="text-align:center; max-width:1200px;">
  <h2>Este es Manolo</h2>
    <p>
      <b>Manolo es un buscador de las personas</b> que visitan entidades del
      Estado peruano.
      <br />
      Los datos pueden ser descargados de instituciones que tengan sus
      registro de visita en línea.
    </p>

    <div class='well'>
      Puedes buscar por nombre o palabra clave. Por ejemplo tipea
      <b>ROMULO</b> y hacer click en "Buscar".
    </div>


  <div class="row">
    <div class="col-xs-12 col-md-12 col-lg-12">
      <form action="/search" method="get" class="form-inline" role="search">
        <div class="form-group">
           <label class="sr-only" for="query">Keyword</label>
           <input style="width:250px;" type="text" id="query" name="q"
                             class="form-control"
                             placeholder="Tipea persona o palabra clave" />
        </div>
          <button type="submit" class="btn btn-info" id="search_button">
                      <i class="fa fa-search"></i>
                      Buscar
          </button>
      </form>
    </div>
  </div><!-- row -->

  <br />
  <hr>


  <div class="row">
    <div class="col-xs-9 col-xs-offset-1  col-sm-8 col-sm-offset-2  col-md-6 col-md-offset-3">
      <h3 class="text-left">La base de datos de Manolo <i class="fa fa-database"></i></h3>

      <p class="text-left">Contiene registros de visitas de las siguientes instituciones:</p>
      <ol class="list-group text-left">
        <li class=list-group-item>8. Ministerio <a href="http://www.peru.gob.pe/transparencia/pep_transparencia_citas.asp?cod_institucion=137">de Energía y Minas</a>
          <span class="label label-danger"><b>Nuevo</b></span></li>
        <li class="list-group-item">7. Organismo Supervisor de las Contrataciones del Estado, <a href="http://visitas.osce.gob.pe/controlVisitas/index.php?r=consultas/visitaConsulta/index">OSCE</a></li>
        <li class=list-group-item>6. Ministerio de <a href="http://www.mindef.gob.pe/visitas/qryvisitas.php">Defensa</a></li>
        <li class=list-group-item>5. <a href="http://www.peru.gob.pe/transparencia/pep_transparencia_citas.asp?cod_institucion=182">INPE</a></li>
        <li class=list-group-item>4. Ministerio <a href="http://webapp.mimp.gob.pe:8080/visitaweb/ListarVisitas.do">de la Mujer</a></li>
        <li class=list-group-item>3. Presidencia del <a href="http://hera.pcm.gob.pe/Visitas/controlVisitas/index.php?r=consultas/visitaConsulta/index">Consejo de Ministros</a></li>
        <li class=list-group-item>2. <a href="http://www.presidencia.gob.pe/visitas/consulta_visitas.php">Presidencia</a></li>
        <li class=list-group-item>1. Ministerio <a href="http://geo.vivienda.gob.pe/Visitas/controlVisitas/index.php?r=consultas/visitaConsulta/index">de Vivienda</a></li>
      </ol>
    </div>
  </div><!-- row -->


  <br />
  <hr>


  <div class="row">
    <div class="col-xs-9 col-xs-offset-1  col-sm-8 col-sm-offset-2  col-md-6 col-md-offset-3">
      <h3 class="text-left">La información contenida en Manolo ha sido utilizada para estas notas
                            periodísticas:
      </h3>

      <p class="text-left">
        {% load staticfiles %}
        <img src="{% static 'img/2014-12-01_portadas.png' %}" />
      </p>

      <h4 class="text-left">
        Tales medios rebotaron la nota periodística de
        <a href="https://twitter.com/martinhidalgo">Martín Hidalgo</a> publicada en el
        <a href="http://utero.pe/2014/11/24/exclusivo-chocherin-el-socio-de-martin-belaunde-visito-palacio-de-gobierno-33-veces/">utero.pe</a>:

        <br />
        <br />
        <a href="http://utero.pe/2014/11/24/exclusivo-chocherin-el-socio-de-martin-belaunde-visito-palacio-de-gobierno-33-veces/">
          EXCLUSIVO: “CHOCHERÍN”, EL SOCIO DE MARTÍN BELAUNDE, VISITÓ PALACIO DE GOBIERNO 33 VECES
        </a>
      </h4>
    </div>
  </div><!-- row -->


</div><!-- container -->

<br />

{% endblock content %}
